# AI Pattern Analysis: routes.py

**Generated:** 2025-12-27 19:21:54
**Date:** 2025-12-27
**Time:** 19:21:54

---

Found 490 potential issues:

- 🔴 HIGH: 473
- 🟡 MEDIUM: 0
- 🟢 LOW: 17

| Severity | Line | Pattern | Message | Suggestion |
|----------|------|---------|---------|------------|
| 🔴 HIGH | 20 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 21 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 22 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 23 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 24 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 25 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 26 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 27 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 28 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 29 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 30 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 31 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 32 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 33 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 34 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 35 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 36 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 37 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 38 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 39 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 40 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 41 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 42 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 43 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 44 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 45 | `copy_paste_blocks` | Potential copy-paste from line 15 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 228 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 229 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 230 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 231 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 232 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 233 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 234 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 235 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 328 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 386 | `copy_paste_blocks` | Potential copy-paste from line 250 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 388 | `copy_paste_blocks` | Potential copy-paste from line 252 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 389 | `copy_paste_blocks` | Potential copy-paste from line 253 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 392 | `copy_paste_blocks` | Potential copy-paste from line 256 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 393 | `copy_paste_blocks` | Potential copy-paste from line 257 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 424 | `copy_paste_blocks` | Potential copy-paste from line 405 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 425 | `copy_paste_blocks` | Potential copy-paste from line 406 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 614 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 615 | `copy_paste_blocks` | Potential copy-paste from line 236 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 636 | `copy_paste_blocks` | Potential copy-paste from line 498 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 637 | `copy_paste_blocks` | Potential copy-paste from line 499 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 638 | `copy_paste_blocks` | Potential copy-paste from line 500 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 639 | `copy_paste_blocks` | Potential copy-paste from line 501 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 649 | `copy_paste_blocks` | Potential copy-paste from line 523 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 650 | `copy_paste_blocks` | Potential copy-paste from line 523 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 651 | `copy_paste_blocks` | Potential copy-paste from line 523 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 667 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 668 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 669 | `copy_paste_blocks` | Potential copy-paste from line 629 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 695 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 696 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 733 | `copy_paste_blocks` | Potential copy-paste from line 693 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 734 | `copy_paste_blocks` | Potential copy-paste from line 694 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 735 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 736 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 737 | `copy_paste_blocks` | Potential copy-paste from line 629 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 738 | `copy_paste_blocks` | Potential copy-paste from line 630 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 740 | `copy_paste_blocks` | Potential copy-paste from line 632 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 741 | `copy_paste_blocks` | Potential copy-paste from line 633 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 761 | `copy_paste_blocks` | Potential copy-paste from line 619 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 770 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 844 | `copy_paste_blocks` | Potential copy-paste from line 522 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 845 | `copy_paste_blocks` | Potential copy-paste from line 820 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 846 | `copy_paste_blocks` | Potential copy-paste from line 682 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 847 | `copy_paste_blocks` | Potential copy-paste from line 683 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 878 | `copy_paste_blocks` | Potential copy-paste from line 819 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 879 | `copy_paste_blocks` | Potential copy-paste from line 820 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 880 | `copy_paste_blocks` | Potential copy-paste from line 821 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 881 | `copy_paste_blocks` | Potential copy-paste from line 822 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 888 | `copy_paste_blocks` | Potential copy-paste from line 648 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 889 | `copy_paste_blocks` | Potential copy-paste from line 523 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 890 | `copy_paste_blocks` | Potential copy-paste from line 526 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 891 | `copy_paste_blocks` | Potential copy-paste from line 527 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 904 | `copy_paste_blocks` | Potential copy-paste from line 768 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 905 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 906 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 924 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 925 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 926 | `copy_paste_blocks` | Potential copy-paste from line 629 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1048 | `copy_paste_blocks` | Potential copy-paste from line 1034 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1049 | `copy_paste_blocks` | Potential copy-paste from line 1035 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1050 | `copy_paste_blocks` | Potential copy-paste from line 1036 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1051 | `copy_paste_blocks` | Potential copy-paste from line 1037 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1052 | `copy_paste_blocks` | Potential copy-paste from line 1038 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1053 | `copy_paste_blocks` | Potential copy-paste from line 1039 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1054 | `copy_paste_blocks` | Potential copy-paste from line 1040 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1055 | `copy_paste_blocks` | Potential copy-paste from line 1041 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1056 | `copy_paste_blocks` | Potential copy-paste from line 1042 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1074 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1075 | `copy_paste_blocks` | Potential copy-paste from line 236 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1182 | `copy_paste_blocks` | Potential copy-paste from line 727 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1197 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1198 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1258 | `copy_paste_blocks` | Potential copy-paste from line 76 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1259 | `copy_paste_blocks` | Potential copy-paste from line 77 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1260 | `copy_paste_blocks` | Potential copy-paste from line 78 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1261 | `copy_paste_blocks` | Potential copy-paste from line 79 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1262 | `copy_paste_blocks` | Potential copy-paste from line 80 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1263 | `copy_paste_blocks` | Potential copy-paste from line 81 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1264 | `copy_paste_blocks` | Potential copy-paste from line 82 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1265 | `copy_paste_blocks` | Potential copy-paste from line 83 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1266 | `copy_paste_blocks` | Potential copy-paste from line 84 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1267 | `copy_paste_blocks` | Potential copy-paste from line 85 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1268 | `copy_paste_blocks` | Potential copy-paste from line 86 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1269 | `copy_paste_blocks` | Potential copy-paste from line 87 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1270 | `copy_paste_blocks` | Potential copy-paste from line 88 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1271 | `copy_paste_blocks` | Potential copy-paste from line 89 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1272 | `copy_paste_blocks` | Potential copy-paste from line 90 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1274 | `copy_paste_blocks` | Potential copy-paste from line 92 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1275 | `copy_paste_blocks` | Potential copy-paste from line 93 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1277 | `copy_paste_blocks` | Potential copy-paste from line 95 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1278 | `copy_paste_blocks` | Potential copy-paste from line 96 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1281 | `copy_paste_blocks` | Potential copy-paste from line 99 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1282 | `copy_paste_blocks` | Potential copy-paste from line 100 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1283 | `copy_paste_blocks` | Potential copy-paste from line 101 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1284 | `copy_paste_blocks` | Potential copy-paste from line 102 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1287 | `copy_paste_blocks` | Potential copy-paste from line 105 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1288 | `copy_paste_blocks` | Potential copy-paste from line 106 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1289 | `copy_paste_blocks` | Potential copy-paste from line 107 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1290 | `copy_paste_blocks` | Potential copy-paste from line 108 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1291 | `copy_paste_blocks` | Potential copy-paste from line 109 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1292 | `copy_paste_blocks` | Potential copy-paste from line 110 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1293 | `copy_paste_blocks` | Potential copy-paste from line 111 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1294 | `copy_paste_blocks` | Potential copy-paste from line 112 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1297 | `copy_paste_blocks` | Potential copy-paste from line 115 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1298 | `copy_paste_blocks` | Potential copy-paste from line 116 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1299 | `copy_paste_blocks` | Potential copy-paste from line 117 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1302 | `copy_paste_blocks` | Potential copy-paste from line 120 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1303 | `copy_paste_blocks` | Potential copy-paste from line 121 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1304 | `copy_paste_blocks` | Potential copy-paste from line 122 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1305 | `copy_paste_blocks` | Potential copy-paste from line 123 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1306 | `copy_paste_blocks` | Potential copy-paste from line 124 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1307 | `copy_paste_blocks` | Potential copy-paste from line 125 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1308 | `copy_paste_blocks` | Potential copy-paste from line 126 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1311 | `copy_paste_blocks` | Potential copy-paste from line 129 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1312 | `copy_paste_blocks` | Potential copy-paste from line 130 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1314 | `copy_paste_blocks` | Potential copy-paste from line 132 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1315 | `copy_paste_blocks` | Potential copy-paste from line 133 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1318 | `copy_paste_blocks` | Potential copy-paste from line 136 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1319 | `copy_paste_blocks` | Potential copy-paste from line 137 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1320 | `copy_paste_blocks` | Potential copy-paste from line 138 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1321 | `copy_paste_blocks` | Potential copy-paste from line 139 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1322 | `copy_paste_blocks` | Potential copy-paste from line 140 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1323 | `copy_paste_blocks` | Potential copy-paste from line 141 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1324 | `copy_paste_blocks` | Potential copy-paste from line 142 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1325 | `copy_paste_blocks` | Potential copy-paste from line 143 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1326 | `copy_paste_blocks` | Potential copy-paste from line 144 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1327 | `copy_paste_blocks` | Potential copy-paste from line 145 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1328 | `copy_paste_blocks` | Potential copy-paste from line 146 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1329 | `copy_paste_blocks` | Potential copy-paste from line 147 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1330 | `copy_paste_blocks` | Potential copy-paste from line 148 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1331 | `copy_paste_blocks` | Potential copy-paste from line 149 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1332 | `copy_paste_blocks` | Potential copy-paste from line 150 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1333 | `copy_paste_blocks` | Potential copy-paste from line 151 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1334 | `copy_paste_blocks` | Potential copy-paste from line 152 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1335 | `copy_paste_blocks` | Potential copy-paste from line 153 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1336 | `copy_paste_blocks` | Potential copy-paste from line 154 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1337 | `copy_paste_blocks` | Potential copy-paste from line 155 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1338 | `copy_paste_blocks` | Potential copy-paste from line 156 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1339 | `copy_paste_blocks` | Potential copy-paste from line 157 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1340 | `copy_paste_blocks` | Potential copy-paste from line 158 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1341 | `copy_paste_blocks` | Potential copy-paste from line 159 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1342 | `copy_paste_blocks` | Potential copy-paste from line 160 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1345 | `copy_paste_blocks` | Potential copy-paste from line 163 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1346 | `copy_paste_blocks` | Potential copy-paste from line 164 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1347 | `copy_paste_blocks` | Potential copy-paste from line 165 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1348 | `copy_paste_blocks` | Potential copy-paste from line 166 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1349 | `copy_paste_blocks` | Potential copy-paste from line 167 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1350 | `copy_paste_blocks` | Potential copy-paste from line 168 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1351 | `copy_paste_blocks` | Potential copy-paste from line 169 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1352 | `copy_paste_blocks` | Potential copy-paste from line 170 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1355 | `copy_paste_blocks` | Potential copy-paste from line 173 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1356 | `copy_paste_blocks` | Potential copy-paste from line 174 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1357 | `copy_paste_blocks` | Potential copy-paste from line 175 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1358 | `copy_paste_blocks` | Potential copy-paste from line 176 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1359 | `copy_paste_blocks` | Potential copy-paste from line 177 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1360 | `copy_paste_blocks` | Potential copy-paste from line 178 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1361 | `copy_paste_blocks` | Potential copy-paste from line 179 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1362 | `copy_paste_blocks` | Potential copy-paste from line 180 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1363 | `copy_paste_blocks` | Potential copy-paste from line 181 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1366 | `copy_paste_blocks` | Potential copy-paste from line 184 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1367 | `copy_paste_blocks` | Potential copy-paste from line 185 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1368 | `copy_paste_blocks` | Potential copy-paste from line 186 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1369 | `copy_paste_blocks` | Potential copy-paste from line 187 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1370 | `copy_paste_blocks` | Potential copy-paste from line 188 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1371 | `copy_paste_blocks` | Potential copy-paste from line 189 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1372 | `copy_paste_blocks` | Potential copy-paste from line 190 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1373 | `copy_paste_blocks` | Potential copy-paste from line 191 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1374 | `copy_paste_blocks` | Potential copy-paste from line 192 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1375 | `copy_paste_blocks` | Potential copy-paste from line 193 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1376 | `copy_paste_blocks` | Potential copy-paste from line 194 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1377 | `copy_paste_blocks` | Potential copy-paste from line 195 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1378 | `copy_paste_blocks` | Potential copy-paste from line 196 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1381 | `copy_paste_blocks` | Potential copy-paste from line 199 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1382 | `copy_paste_blocks` | Potential copy-paste from line 200 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1383 | `copy_paste_blocks` | Potential copy-paste from line 201 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1384 | `copy_paste_blocks` | Potential copy-paste from line 202 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1385 | `copy_paste_blocks` | Potential copy-paste from line 203 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1388 | `copy_paste_blocks` | Potential copy-paste from line 206 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1389 | `copy_paste_blocks` | Potential copy-paste from line 207 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1390 | `copy_paste_blocks` | Potential copy-paste from line 208 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1391 | `copy_paste_blocks` | Potential copy-paste from line 209 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1392 | `copy_paste_blocks` | Potential copy-paste from line 210 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1393 | `copy_paste_blocks` | Potential copy-paste from line 211 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1394 | `copy_paste_blocks` | Potential copy-paste from line 212 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1395 | `copy_paste_blocks` | Potential copy-paste from line 213 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1396 | `copy_paste_blocks` | Potential copy-paste from line 214 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1397 | `copy_paste_blocks` | Potential copy-paste from line 215 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1398 | `copy_paste_blocks` | Potential copy-paste from line 216 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1401 | `copy_paste_blocks` | Potential copy-paste from line 219 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1402 | `copy_paste_blocks` | Potential copy-paste from line 220 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1404 | `copy_paste_blocks` | Potential copy-paste from line 222 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1405 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1406 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1407 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1408 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1409 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1410 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1411 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1412 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1413 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1414 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1415 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1416 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1417 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1418 | `copy_paste_blocks` | Potential copy-paste from line 236 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1421 | `copy_paste_blocks` | Potential copy-paste from line 1181 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1422 | `copy_paste_blocks` | Potential copy-paste from line 727 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1425 | `copy_paste_blocks` | Potential copy-paste from line 1192 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1426 | `copy_paste_blocks` | Potential copy-paste from line 1193 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1427 | `copy_paste_blocks` | Potential copy-paste from line 1194 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1428 | `copy_paste_blocks` | Potential copy-paste from line 1195 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1429 | `copy_paste_blocks` | Potential copy-paste from line 1196 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1430 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1431 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1432 | `copy_paste_blocks` | Potential copy-paste from line 1199 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1433 | `copy_paste_blocks` | Potential copy-paste from line 1200 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1435 | `copy_paste_blocks` | Potential copy-paste from line 1202 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1436 | `copy_paste_blocks` | Potential copy-paste from line 1203 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1438 | `copy_paste_blocks` | Potential copy-paste from line 1205 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1440 | `copy_paste_blocks` | Potential copy-paste from line 1207 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1441 | `copy_paste_blocks` | Potential copy-paste from line 1208 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1442 | `copy_paste_blocks` | Potential copy-paste from line 1209 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1443 | `copy_paste_blocks` | Potential copy-paste from line 1210 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1446 | `copy_paste_blocks` | Potential copy-paste from line 1213 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1448 | `copy_paste_blocks` | Potential copy-paste from line 1215 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1449 | `copy_paste_blocks` | Potential copy-paste from line 1216 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1450 | `copy_paste_blocks` | Potential copy-paste from line 1217 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1451 | `copy_paste_blocks` | Potential copy-paste from line 1218 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1452 | `copy_paste_blocks` | Potential copy-paste from line 1219 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1454 | `copy_paste_blocks` | Potential copy-paste from line 1221 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1457 | `copy_paste_blocks` | Potential copy-paste from line 1224 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1458 | `copy_paste_blocks` | Potential copy-paste from line 1225 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1459 | `copy_paste_blocks` | Potential copy-paste from line 1226 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1460 | `copy_paste_blocks` | Potential copy-paste from line 1227 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1461 | `copy_paste_blocks` | Potential copy-paste from line 1228 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1462 | `copy_paste_blocks` | Potential copy-paste from line 1229 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1463 | `copy_paste_blocks` | Potential copy-paste from line 1230 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1464 | `copy_paste_blocks` | Potential copy-paste from line 1231 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1465 | `copy_paste_blocks` | Potential copy-paste from line 1232 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1466 | `copy_paste_blocks` | Potential copy-paste from line 1233 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1469 | `copy_paste_blocks` | Potential copy-paste from line 1236 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1470 | `copy_paste_blocks` | Potential copy-paste from line 1237 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1471 | `copy_paste_blocks` | Potential copy-paste from line 1238 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1472 | `copy_paste_blocks` | Potential copy-paste from line 1239 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1473 | `copy_paste_blocks` | Potential copy-paste from line 1240 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1474 | `copy_paste_blocks` | Potential copy-paste from line 1241 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1475 | `copy_paste_blocks` | Potential copy-paste from line 1242 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1476 | `copy_paste_blocks` | Potential copy-paste from line 1243 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1477 | `copy_paste_blocks` | Potential copy-paste from line 1244 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1478 | `copy_paste_blocks` | Potential copy-paste from line 1245 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1479 | `copy_paste_blocks` | Potential copy-paste from line 1246 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1480 | `copy_paste_blocks` | Potential copy-paste from line 1247 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1481 | `copy_paste_blocks` | Potential copy-paste from line 1248 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1486 | `copy_paste_blocks` | Potential copy-paste from line 240 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1494 | `copy_paste_blocks` | Potential copy-paste from line 243 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1495 | `copy_paste_blocks` | Potential copy-paste from line 244 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1496 | `copy_paste_blocks` | Potential copy-paste from line 245 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1498 | `copy_paste_blocks` | Potential copy-paste from line 247 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1499 | `copy_paste_blocks` | Potential copy-paste from line 248 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1500 | `copy_paste_blocks` | Potential copy-paste from line 249 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1501 | `copy_paste_blocks` | Potential copy-paste from line 250 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1503 | `copy_paste_blocks` | Potential copy-paste from line 252 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1504 | `copy_paste_blocks` | Potential copy-paste from line 253 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1507 | `copy_paste_blocks` | Potential copy-paste from line 256 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1508 | `copy_paste_blocks` | Potential copy-paste from line 257 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1509 | `copy_paste_blocks` | Potential copy-paste from line 258 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1510 | `copy_paste_blocks` | Potential copy-paste from line 259 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1511 | `copy_paste_blocks` | Potential copy-paste from line 260 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1512 | `copy_paste_blocks` | Potential copy-paste from line 261 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1515 | `copy_paste_blocks` | Potential copy-paste from line 264 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1516 | `copy_paste_blocks` | Potential copy-paste from line 265 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1517 | `copy_paste_blocks` | Potential copy-paste from line 266 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1518 | `copy_paste_blocks` | Potential copy-paste from line 267 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1519 | `copy_paste_blocks` | Potential copy-paste from line 268 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1520 | `copy_paste_blocks` | Potential copy-paste from line 269 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1521 | `copy_paste_blocks` | Potential copy-paste from line 270 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1522 | `copy_paste_blocks` | Potential copy-paste from line 271 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1523 | `copy_paste_blocks` | Potential copy-paste from line 272 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1524 | `copy_paste_blocks` | Potential copy-paste from line 273 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1525 | `copy_paste_blocks` | Potential copy-paste from line 274 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1526 | `copy_paste_blocks` | Potential copy-paste from line 275 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1527 | `copy_paste_blocks` | Potential copy-paste from line 276 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1528 | `copy_paste_blocks` | Potential copy-paste from line 277 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1529 | `copy_paste_blocks` | Potential copy-paste from line 278 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1530 | `copy_paste_blocks` | Potential copy-paste from line 279 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1531 | `copy_paste_blocks` | Potential copy-paste from line 280 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1532 | `copy_paste_blocks` | Potential copy-paste from line 281 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1533 | `copy_paste_blocks` | Potential copy-paste from line 282 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1534 | `copy_paste_blocks` | Potential copy-paste from line 283 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1535 | `copy_paste_blocks` | Potential copy-paste from line 284 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1536 | `copy_paste_blocks` | Potential copy-paste from line 285 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1537 | `copy_paste_blocks` | Potential copy-paste from line 286 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1538 | `copy_paste_blocks` | Potential copy-paste from line 287 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1541 | `copy_paste_blocks` | Potential copy-paste from line 290 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1543 | `copy_paste_blocks` | Potential copy-paste from line 292 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1544 | `copy_paste_blocks` | Potential copy-paste from line 293 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1546 | `copy_paste_blocks` | Potential copy-paste from line 295 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1547 | `copy_paste_blocks` | Potential copy-paste from line 296 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1548 | `copy_paste_blocks` | Potential copy-paste from line 297 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1549 | `copy_paste_blocks` | Potential copy-paste from line 298 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1550 | `copy_paste_blocks` | Potential copy-paste from line 299 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1551 | `copy_paste_blocks` | Potential copy-paste from line 300 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1552 | `copy_paste_blocks` | Potential copy-paste from line 301 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1553 | `copy_paste_blocks` | Potential copy-paste from line 302 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1556 | `copy_paste_blocks` | Potential copy-paste from line 305 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1558 | `copy_paste_blocks` | Potential copy-paste from line 307 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1560 | `copy_paste_blocks` | Potential copy-paste from line 309 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1561 | `copy_paste_blocks` | Potential copy-paste from line 310 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1562 | `copy_paste_blocks` | Potential copy-paste from line 311 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1563 | `copy_paste_blocks` | Potential copy-paste from line 312 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1564 | `copy_paste_blocks` | Potential copy-paste from line 313 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1565 | `copy_paste_blocks` | Potential copy-paste from line 314 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1566 | `copy_paste_blocks` | Potential copy-paste from line 315 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1567 | `copy_paste_blocks` | Potential copy-paste from line 316 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1568 | `copy_paste_blocks` | Potential copy-paste from line 317 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1570 | `copy_paste_blocks` | Potential copy-paste from line 319 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1571 | `copy_paste_blocks` | Potential copy-paste from line 320 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1572 | `copy_paste_blocks` | Potential copy-paste from line 321 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1573 | `copy_paste_blocks` | Potential copy-paste from line 322 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1574 | `copy_paste_blocks` | Potential copy-paste from line 323 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1576 | `copy_paste_blocks` | Potential copy-paste from line 325 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1577 | `copy_paste_blocks` | Potential copy-paste from line 326 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1578 | `copy_paste_blocks` | Potential copy-paste from line 327 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1579 | `copy_paste_blocks` | Potential copy-paste from line 223 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1580 | `copy_paste_blocks` | Potential copy-paste from line 329 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1581 | `copy_paste_blocks` | Potential copy-paste from line 330 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1582 | `copy_paste_blocks` | Potential copy-paste from line 331 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1583 | `copy_paste_blocks` | Potential copy-paste from line 332 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1584 | `copy_paste_blocks` | Potential copy-paste from line 333 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1585 | `copy_paste_blocks` | Potential copy-paste from line 334 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1586 | `copy_paste_blocks` | Potential copy-paste from line 335 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1587 | `copy_paste_blocks` | Potential copy-paste from line 336 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1590 | `copy_paste_blocks` | Potential copy-paste from line 339 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1591 | `copy_paste_blocks` | Potential copy-paste from line 340 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1592 | `copy_paste_blocks` | Potential copy-paste from line 341 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1593 | `copy_paste_blocks` | Potential copy-paste from line 342 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1596 | `copy_paste_blocks` | Potential copy-paste from line 345 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1597 | `copy_paste_blocks` | Potential copy-paste from line 346 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1598 | `copy_paste_blocks` | Potential copy-paste from line 347 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1600 | `copy_paste_blocks` | Potential copy-paste from line 349 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1601 | `copy_paste_blocks` | Potential copy-paste from line 350 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1602 | `copy_paste_blocks` | Potential copy-paste from line 351 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1603 | `copy_paste_blocks` | Potential copy-paste from line 352 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1604 | `copy_paste_blocks` | Potential copy-paste from line 353 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1605 | `copy_paste_blocks` | Potential copy-paste from line 354 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1606 | `copy_paste_blocks` | Potential copy-paste from line 355 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1607 | `copy_paste_blocks` | Potential copy-paste from line 356 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1608 | `copy_paste_blocks` | Potential copy-paste from line 357 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1609 | `copy_paste_blocks` | Potential copy-paste from line 358 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1610 | `copy_paste_blocks` | Potential copy-paste from line 359 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1611 | `copy_paste_blocks` | Potential copy-paste from line 360 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1612 | `copy_paste_blocks` | Potential copy-paste from line 361 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1613 | `copy_paste_blocks` | Potential copy-paste from line 362 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1614 | `copy_paste_blocks` | Potential copy-paste from line 363 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1617 | `copy_paste_blocks` | Potential copy-paste from line 366 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1618 | `copy_paste_blocks` | Potential copy-paste from line 367 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1619 | `copy_paste_blocks` | Potential copy-paste from line 368 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1620 | `copy_paste_blocks` | Potential copy-paste from line 369 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1634 | `copy_paste_blocks` | Potential copy-paste from line 666 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1635 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1636 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1637 | `copy_paste_blocks` | Potential copy-paste from line 1199 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1669 | `copy_paste_blocks` | Potential copy-paste from line 379 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1670 | `copy_paste_blocks` | Potential copy-paste from line 380 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1671 | `copy_paste_blocks` | Potential copy-paste from line 381 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1673 | `copy_paste_blocks` | Potential copy-paste from line 383 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1674 | `copy_paste_blocks` | Potential copy-paste from line 384 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1675 | `copy_paste_blocks` | Potential copy-paste from line 385 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1676 | `copy_paste_blocks` | Potential copy-paste from line 250 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1678 | `copy_paste_blocks` | Potential copy-paste from line 252 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1679 | `copy_paste_blocks` | Potential copy-paste from line 253 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1682 | `copy_paste_blocks` | Potential copy-paste from line 256 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1683 | `copy_paste_blocks` | Potential copy-paste from line 257 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1684 | `copy_paste_blocks` | Potential copy-paste from line 394 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1685 | `copy_paste_blocks` | Potential copy-paste from line 395 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1686 | `copy_paste_blocks` | Potential copy-paste from line 396 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1687 | `copy_paste_blocks` | Potential copy-paste from line 397 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1690 | `copy_paste_blocks` | Potential copy-paste from line 400 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1691 | `copy_paste_blocks` | Potential copy-paste from line 401 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1692 | `copy_paste_blocks` | Potential copy-paste from line 402 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1694 | `copy_paste_blocks` | Potential copy-paste from line 404 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1695 | `copy_paste_blocks` | Potential copy-paste from line 405 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1696 | `copy_paste_blocks` | Potential copy-paste from line 406 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1697 | `copy_paste_blocks` | Potential copy-paste from line 407 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1698 | `copy_paste_blocks` | Potential copy-paste from line 408 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1699 | `copy_paste_blocks` | Potential copy-paste from line 409 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1700 | `copy_paste_blocks` | Potential copy-paste from line 410 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1701 | `copy_paste_blocks` | Potential copy-paste from line 411 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1704 | `copy_paste_blocks` | Potential copy-paste from line 414 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1706 | `copy_paste_blocks` | Potential copy-paste from line 416 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1707 | `copy_paste_blocks` | Potential copy-paste from line 417 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1709 | `copy_paste_blocks` | Potential copy-paste from line 419 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1710 | `copy_paste_blocks` | Potential copy-paste from line 420 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1712 | `copy_paste_blocks` | Potential copy-paste from line 422 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1713 | `copy_paste_blocks` | Potential copy-paste from line 423 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1714 | `copy_paste_blocks` | Potential copy-paste from line 405 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1715 | `copy_paste_blocks` | Potential copy-paste from line 406 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1716 | `copy_paste_blocks` | Potential copy-paste from line 426 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1717 | `copy_paste_blocks` | Potential copy-paste from line 427 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1718 | `copy_paste_blocks` | Potential copy-paste from line 428 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1719 | `copy_paste_blocks` | Potential copy-paste from line 429 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1720 | `copy_paste_blocks` | Potential copy-paste from line 430 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1721 | `copy_paste_blocks` | Potential copy-paste from line 431 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1722 | `copy_paste_blocks` | Potential copy-paste from line 432 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1723 | `copy_paste_blocks` | Potential copy-paste from line 433 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1724 | `copy_paste_blocks` | Potential copy-paste from line 434 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1725 | `copy_paste_blocks` | Potential copy-paste from line 435 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1726 | `copy_paste_blocks` | Potential copy-paste from line 436 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1727 | `copy_paste_blocks` | Potential copy-paste from line 437 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1728 | `copy_paste_blocks` | Potential copy-paste from line 438 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1729 | `copy_paste_blocks` | Potential copy-paste from line 439 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1730 | `copy_paste_blocks` | Potential copy-paste from line 440 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1731 | `copy_paste_blocks` | Potential copy-paste from line 441 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1732 | `copy_paste_blocks` | Potential copy-paste from line 442 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1733 | `copy_paste_blocks` | Potential copy-paste from line 443 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1736 | `copy_paste_blocks` | Potential copy-paste from line 446 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1737 | `copy_paste_blocks` | Potential copy-paste from line 447 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1738 | `copy_paste_blocks` | Potential copy-paste from line 448 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1740 | `copy_paste_blocks` | Potential copy-paste from line 450 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1741 | `copy_paste_blocks` | Potential copy-paste from line 451 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1742 | `copy_paste_blocks` | Potential copy-paste from line 452 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1743 | `copy_paste_blocks` | Potential copy-paste from line 453 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1744 | `copy_paste_blocks` | Potential copy-paste from line 454 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1745 | `copy_paste_blocks` | Potential copy-paste from line 455 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1746 | `copy_paste_blocks` | Potential copy-paste from line 456 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1747 | `copy_paste_blocks` | Potential copy-paste from line 457 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1748 | `copy_paste_blocks` | Potential copy-paste from line 458 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1749 | `copy_paste_blocks` | Potential copy-paste from line 459 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1752 | `copy_paste_blocks` | Potential copy-paste from line 462 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1753 | `copy_paste_blocks` | Potential copy-paste from line 463 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1754 | `copy_paste_blocks` | Potential copy-paste from line 464 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1755 | `copy_paste_blocks` | Potential copy-paste from line 465 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1756 | `copy_paste_blocks` | Potential copy-paste from line 466 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1757 | `copy_paste_blocks` | Potential copy-paste from line 467 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1758 | `copy_paste_blocks` | Potential copy-paste from line 468 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1759 | `copy_paste_blocks` | Potential copy-paste from line 469 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1762 | `copy_paste_blocks` | Potential copy-paste from line 472 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1763 | `copy_paste_blocks` | Potential copy-paste from line 473 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1773 | `copy_paste_blocks` | Potential copy-paste from line 1630 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1774 | `copy_paste_blocks` | Potential copy-paste from line 1631 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1775 | `copy_paste_blocks` | Potential copy-paste from line 1632 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1776 | `copy_paste_blocks` | Potential copy-paste from line 1633 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1777 | `copy_paste_blocks` | Potential copy-paste from line 666 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1778 | `copy_paste_blocks` | Potential copy-paste from line 627 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1779 | `copy_paste_blocks` | Potential copy-paste from line 628 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1780 | `copy_paste_blocks` | Potential copy-paste from line 1199 | Extract duplicated logic into a reusable function. |
| 🔴 HIGH | 1781 | `copy_paste_blocks` | Potential copy-paste from line 1638 | Extract duplicated logic into a reusable function. |
| 🟢 LOW | 486 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 627 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 667 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 695 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 735 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 770 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 839 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 861 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 905 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 924 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 954 | `generic_naming` | Generic variable name: 'data' | Use a more descriptive name. |
| 🟢 LOW | 1085 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 1113 | `generic_naming` | Generic variable name: 'data' | Use a more descriptive name. |
| 🟢 LOW | 1197 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 1430 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 1635 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
| 🟢 LOW | 1778 | `generic_naming` | Generic variable name: 'result' | Use a more descriptive name. |
